@@ -63,6 +63,15 @@ static bool allowedModificationsWithoutRevisionUpdate(const Incidence::Ptr &inci
     return dirtyFields == alarmOnlyModify;
 }
 
+static void updateHandlerPrivacyPolicy(ITIPHandlerHelper *helper, IncidenceChanger::InvitationPrivacyFlags flags)
+{
+    ITIPHandlerHelper::MessagePrivacyFlags helperFlags;
+    helperFlags.setFlag(ITIPHandlerHelper::MessagePrivacySign, (flags & IncidenceChanger::InvitationPrivacySign) == IncidenceChanger::InvitationPrivacySign);
+    helperFlags.setFlag(ITIPHandlerHelper::MessagePrivacyEncrypt,
+                        (flags & IncidenceChanger::InvitationPrivacyEncrypt) == IncidenceChanger::InvitationPrivacyEncrypt);
+    helper->setMessagePrivacy(helperFlags);
+}
+
 namespace Akonadi
 {
 // Does a queued emit, with QMetaObject::invokeMethod
@@ -97,7 +106,7 @@ emitModifyFinished(IncidenceChanger *changer, int changeId, const Akonadi::Item
 // Does a queued emit, with QMetaObject::invokeMethod
 static void emitDeleteFinished(IncidenceChanger *changer,
                                int changeId,
-                               const QVector<Akonadi::Item::Id> &itemIdList,
+                               const QList<Akonadi::Item::Id> &itemIdList,
                                IncidenceChanger::ResultCode resultCode,
                                const QString &errorString)
 {
@@ -105,7 +114,7 @@ static void emitDeleteFinished(IncidenceChanger *changer,
                               "deleteFinished",
                               Qt::QueuedConnection,
                               Q_ARG(int, changeId),
-                              Q_ARG(QVector<Akonadi::Item::Id>, itemIdList),
+                              Q_ARG(QList<Akonadi::Item::Id>, itemIdList),
                               Q_ARG(Akonadi::IncidenceChanger::ResultCode, resultCode),
                               Q_ARG(QString, errorString));
 }
@@ -131,7 +140,7 @@ IncidenceChangerPrivate::IncidenceChangerPrivate(bool enableHistory, ITIPHandler
     m_collectionFetchJob = nullptr;
     m_invitationPolicy = IncidenceChanger::InvitationPolicyAsk;
 
-    qRegisterMetaType<QVector<Akonadi::Item::Id>>("QVector<Akonadi::Item::Id>");
+    qRegisterMetaType<QList<Akonadi::Item::Id>>("QList<Akonadi::Item::Id>");
     qRegisterMetaType<Akonadi::Item::Id>("Akonadi::Item::Id");
     qRegisterMetaType<Akonadi::Item>("Akonadi::Item");
     qRegisterMetaType<Akonadi::IncidenceChanger::ResultCode>("Akonadi::IncidenceChanger::ResultCode");
@@ -459,6 +468,7 @@ void IncidenceChangerPrivate::handleInvitationsBeforeChange(const Change::Ptr &c
 
             auto handler = new ITIPHandlerHelper(mFactory, change->parentWidget);
             handler->setParent(this);
+            updateHandlerPrivacyPolicy(handler, m_invitationPrivacy);
 
             if (m_invitationPolicy == IncidenceChanger::InvitationPolicySend) {
                 handler->setDefaultAction(ITIPHandlerDialogDelegate::ActionSendMessage);
@@ -556,6 +566,7 @@ void IncidenceChangerPrivate::handleInvitationsAfterChange(const Change::Ptr &ch
         auto handler = new ITIPHandlerHelper(mFactory, change->parentWidget);
         connect(handler, &ITIPHandlerHelper::finished, change.data(), &Change::emitUserDialogClosedAfterChange);
         handler->setParent(this);
+        updateHandlerPrivacyPolicy(handler, m_invitationPrivacy);
 
         const bool alwaysSend = (m_invitationPolicy == IncidenceChanger::InvitationPolicySend);
         const bool neverSend = (m_invitationPolicy == IncidenceChanger::InvitationPolicyDontSend);
@@ -790,7 +801,7 @@ int IncidenceChanger::deleteIncidences(const Item::List &items, QWidget *parent)
     }
 
     if (itemsToDelete.isEmpty()) {
-        QVector<Akonadi::Item::Id> itemIdList;
+        QList<Akonadi::Item::Id> itemIdList;
         itemIdList.append(Item().id());
         qCDebug(AKONADICALENDAR_LOG) << "Items already deleted or being deleted, skipping";
         const QString errorMessage = i18n("That calendar item was already deleted, or currently being deleted.");
@@ -1168,6 +1179,16 @@ Akonadi::Collection IncidenceChanger::lastCollectionUsed() const
     return d->mLastCollectionUsed;
 }
 
+void IncidenceChanger::setInvitationPrivacy(IncidenceChanger::InvitationPrivacyFlags invitationPrivacy)
+{
+    d->m_invitationPrivacy = invitationPrivacy;
+}
+
+IncidenceChanger::InvitationPrivacyFlags IncidenceChanger::invitationPrivacy() const
+{
+    return d->m_invitationPrivacy;
+}
+
 QString IncidenceChangerPrivate::showErrorDialog(IncidenceChanger::ResultCode resultCode, QWidget *parent)
 {
     QString errorString;
@@ -1368,3 +1389,5 @@ Akonadi::TransactionSequence *AtomicOperation::transaction()
 
     return m_transaction;
 }
+
+#include "moc_incidencechanger.cpp"
